@@ -1,5 +1,5 @@
 package MOP::Role;
-# Abstract: A representation of a role
+# ABSTRACT: A representation of a role
 
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ use MOP::Slot;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.02';
 our $AUTHORITY = 'cpan:STEVAN';
 
 our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object' };
@@ -24,8 +24,8 @@ sub BUILDARGS {
         if ( ref $_[0] ) {
             if ( ref $_[0] eq 'HASH' ) {
                 if ( MOP::Internal::Util::IS_STASH_REF( $_[0] ) ) {
-                    # if it is a stash, grab the name 
-                    %args = ( 
+                    # if it is a stash, grab the name
+                    %args = (
                         name  => MOP::Internal::Util::GET_NAME( $_[0] ),
                         stash => $_[0]
                     );
@@ -797,11 +797,28 @@ __END__
 
 =head1 NAME
 
-MOP::Role
+MOP::Role - A representation of a role
 
 =head1 VERSION
 
-version 0.01
+version 0.02
+
+=head1 DESCRIPTION
+
+A role is simply a package which I<may> have methods, I<may> have slot
+defintions, and I<may> consume other roles.
+
+=head1 CONSTRUCTORS
+
+=over 4
+
+=item L<new( name => $package_name )>
+
+=item L<new( $package_name )>
+
+=item L<new( \%package_stash )>
+
+=back
 
 =head1 METHODS
 
