@@ -8,39 +8,57 @@ use UNIVERSAL::Object;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.02';
 our $AUTHORITY = 'cpan:STEVAN';
 
 our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object' }
-our %HAS; BEGIN {
-    %HAS = (
-        name        => sub { die '[ARGS] You must specify a slot name'        },
-        initializer => sub { die '[ARGS] You must specify a slot initializer' },
-    )
-}
 
 # if called upon to be a CODE ref
 # then return the initializer
 use overload '&{}' => 'initializer', fallback => 1;
 
+sub BUILDARGS {
+    my $class = shift;
+    my $args;
+
+    if ( scalar( @_ ) eq 2 && !(ref $_[0]) && ref $_[1] eq 'CODE' ) {
+        $args = +{ name => $_[0], initializer => $_[1] };
+    }
+    else {
+        $args = $class->SUPER::BUILDARGS( @_ );
+    }
+
+    die '[ARGS] You must specify a slot name'
+        unless $args->{name};
+    die '[ARGS] You must specify a slot initializer'
+        unless $args->{initializer};
+    die '[ARGS] The initializer specified must be a CODE reference'
+        unless ref $args->{initializer} eq 'CODE';
+
+    return $args;
+}
+
 sub CREATE {
     my ($class, $args) = @_;
-    my $proto = $class->SUPER::CREATE( $args );
-
-    die '[ARGS] The initializer specified must be a CODE reference'
-        unless ref $proto->{initializer} eq 'CODE';
-
-    return $proto;
+    # NOTE:
+    # Ideally this instance would actually just be
+    # a reference to an HE (C-level hash entry struct)
+    # but that is not something that is exposed at
+    # the language level. Instead we use an ARRAY
+    # ref to both 1) save space and 2) retain an
+    # illusion of opacity regarding these instances.
+    # - SL
+    return +[ $args->{name}, $args->{initializer} ]
 }
 
 sub name {
     my ($self) = @_;
-    return $self->{name};
+    return $self->[0];
 }
 
 sub initializer {
     my ($self) = @_;
-    return $self->{initializer};
+    return $self->[1];
 }
 
 sub origin_stash {
@@ -79,7 +97,23 @@ MOP::Slot - A representation of a class slot
 
 =head1 VERSION
 
-version 0.01
+version 0.02
+
+=head1 DESCRIPTION
+
+A slot is best thought of as representing a single entry in the
+package scoped C<%HAS> variable. This is basically just building upon the
+conceptual model laid out by L<UNIVERSAL::Object>.
+
+=head1 CONSTRUCTORS
+
+=over 4
+
+=item L<new( name => $name, initializer => $initializer )>
+
+=item L<new( $name, $initializer )>
+
+=back
 
 =head1 METHODS
 
